# -*- coding: utf-8 -*-

#  _              _  __ _
# | |_____      _(_)/ _(_)
# | / __\ \ /\ / / | |_| |
# | \__ \\ V  V /| |  _| |
# |_|___/ \_/\_/ |_|_| |_|

""" a CLI-centric Wi-Fi scanning tool for Windows """
